@@ -883,7 +883,7 @@ class TestF5Converter:
             vs_object = data['VirtualService']
 
             first_vs = [data for data in vs_object if data['name'] == "vs_1_up"]
-            second_vs = [data for data in vs_object if data['name'] == "EngVIP"]
+            second_vs = [data for data in vs_object if data['name'] == "vs_2_up"]
 
             first_pool = first_vs[0]['pool_ref'].split(
                 'name=')[1].split('&')[0]
@@ -1171,6 +1171,24 @@ class TestF5Converter:
         )
         assert output_vs_level_status(self.excel_path)
 
+    @pytest.mark.travis
+    def test_vs_level_status_and_segroup_with_v11(self):
+
+        f5_conv(bigip_config_file=setup.get('config_file_name_v11'),
+                f5_config_version=setup.get('file_version_v11'),
+                controller_version=setup.get('controller_version_v17'),
+                output_file_path=setup.get('output_file_path'),
+                vs_level_status=setup.get('vs_level_status'),
+                f5_ssh_port=setup.get('f5_ssh_port'),
+                segroup=setup.get('segroup')
+                )
+        self.excel_path = os.path.abspath(
+            os.path.join(
+                output_file, 'bigip_v11-ConversionStatus.xlsx'
+            )
+        )
+        assert output_vs_level_status(self.excel_path)
+
     @pytest.mark.skip_travis
     @pytest.mark.TCID1_48_1497_53_0
     def test_reboot_clean_for_segroup_v11_17_1_1(self, cleanup):
@@ -1504,8 +1522,8 @@ class TestF5Converter:
                    'sharedHttpPolicy-HTTP-Policy-Set'
             http_policies = data['HTTPPolicySet']
             shared_http_policy = [policy for policy in http_policies
-                                  if policy['name'] ==
-                                  "sharedHttpPolicy-HTTP-Policy-Set"]
+                                  if "sharedHttpPolicy-HTTP-Policy-Set"
+                                  in policy['name']]
             assert len(shared_http_policy) == 1
 
     @pytest.mark.travis
@@ -1536,8 +1554,8 @@ class TestF5Converter:
                    '_sys_https_redirect'
             http_policies = data['HTTPPolicySet']
             shared_http_policy = [policy for policy in http_policies
-                                  if policy['name'] ==
-                                  "_sys_https_redirect"]
+                                  if "_sys_https_redirect"
+                                  in policy['name']]
             assert len(shared_http_policy) == 1
 
     @pytest.mark.travis
