@@ -4,7 +4,8 @@ import os
 import copy
 import re
 import random
-import urlparse
+from functools import reduce
+
 import ast
 import pandas
 import pexpect
@@ -12,6 +13,7 @@ import avi.migrationtools.netscaler_converter.ns_constants as ns_constants
 from pkg_resources import parse_version
 from xlsxwriter import Workbook
 from openpyxl import load_workbook
+from urllib.parse import urlparse
 from OpenSSL import crypto
 from socket import gethostname
 from avi.migrationtools.netscaler_converter.ns_constants \
@@ -81,7 +83,7 @@ class NsUtil(MigrationUtil):
         global csv_writer_dict_list
         global progressbar_count
         global total_count
-        print "Generating Report For Converted Configuration..."
+        print("Generating Report For Converted Configuration...")
         ptotal = len(ns_config)
         ppcount = 0
         for config_key in ns_config:
@@ -125,9 +127,9 @@ class NsUtil(MigrationUtil):
         for status in STATUS_LIST:
             status_list = [row for row in row_list if
                            row['Status'] == status]
-            print '%s: %s' % (status, len(status_list))
+            print('%s: %s' % (status, len(status_list)))
         # add skipped list of each object at vs level
-        print "Writing Excel Sheet For Converted Configuration..."
+        print("Writing Excel Sheet For Converted Configuration...")
         total_count = total_count + len(row_list)
         if vs_level_status:
             self.vs_per_skipped_setting_for_references(avi_config)
@@ -392,7 +394,7 @@ class NsUtil(MigrationUtil):
                 del tmp_cp["name"]
                 if "description" in tmp_cp:
                     del tmp_cp["description"]
-                if cmp(src_cp, tmp_cp) == 0:
+                if src_cp.items() == tmp_cp.items():
                     LOG.warn('Remove duplicate %s object : %s' % (obj_type,
                                                                   tmp_obj[
                                                                       "name"]))
@@ -448,8 +450,8 @@ class NsUtil(MigrationUtil):
             if parse_version(controller_version) >= parse_version('17.1'):
                 vs_port_list = [int(v['services'][0]['port']) for v in
                                 avi_config['VirtualService']
-                                if v['vip'][0]['ip_address']['addr'] ==
-                                vs['vip'][0]['ip_address']['addr']
+                                if v['vsvip_ref'].split('name=')[1].split('-')[0] ==
+                                vs['vsvip_ref'].split('name=')[1].split('-')[0]
                                 and 'port_range_end' not in v['services'][0]]
             else:
                 vs_port_list = [int(v['services'][0]['port']) for v in
@@ -542,7 +544,7 @@ class NsUtil(MigrationUtil):
 
     def is_shared_same_vip(self, vs, cs_vs_list, avi_config, tenant_name,
                            cloud_name, tenant_ref, cloud_ref,
-                           controller_version, prefix):
+                           controller_version, prefix, input_vrf=None):
         """
         This function check for vs sharing same vip
         :param vs: Name of vs
@@ -554,13 +556,15 @@ class NsUtil(MigrationUtil):
         :param cloud_ref: Reference of cloud
         :param controller_version: controller version
         :param prefix: prefix for objects
+        :param input_vrf: VRF name input
         :return: None
         """
 
         if parse_version(controller_version) >= parse_version('17.1'):
             # Get the list of vs which shared the same vip
-            shared_vip = [v for v in cs_vs_list if v['vip'][0]['ip_address'][
-                'addr'] == vs['vip'][0]['ip_address']['addr'] and
+            shared_vip = [v for v in cs_vs_list if v['vsvip_ref'
+            ].split('name=')[1].split('-')[0] == vs['vsvip_ref'
+            ].split('name=')[1].split('-')[0] and
                           v['services'][0][
                               'port'] == vs['services'][0]['port']]
         else:
@@ -569,13 +573,19 @@ class NsUtil(MigrationUtil):
                               'port'] ==
                           vs['services'][0]['port']]
 
+        if input_vrf:
+            vrf_ref = self.get_object_ref(input_vrf, 'vrfcontext',
+                                          cloud_name=cloud_name)
+        else:
+            vrf_ref = self.get_object_ref('global', 'vrfcontext',
+                                          cloud_name=cloud_name)
+
         if shared_vip:
             return True
         elif parse_version(controller_version) >= parse_version('17.1'):
-            vsvip = vs['vip'][0]['ip_address']['addr']
+            vsvip = vs['vsvip_ref'].split('name=')[1].split('-')[0]
             self.create_update_vsvip(vsvip, avi_config['VsVip'], tenant_ref,
-                                cloud_ref,
-                                prefix=prefix)
+                                cloud_ref, prefix=prefix, vrf_ref=vrf_ref)
             name = vsvip + '-vsvip'
             # Added prefix for objects
             if prefix:
@@ -758,8 +768,9 @@ class NsUtil(MigrationUtil):
                               profile_name, pki_profile_ref))
             else:
                 app_profile = dict()
-                app_profile['name'] = name + '-%s-dummy' % random.randrange(0,
-                                                                            1000)
+                app_profile['name'] = name + '-%s-%s' % (
+                    random.randrange(0, 1000),
+                    ns_constants.PLACE_HOLDER_STR)
                 app_profile['tenant_ref'] = tenant_ref
                 app_profile['type'] = 'APPLICATION_PROFILE_TYPE_HTTP'
                 http_profile = dict()
@@ -905,7 +916,7 @@ class NsUtil(MigrationUtil):
         if parse_version(controller_version) >= parse_version('17.1'):
             avi_config['VirtualService'] = \
                 [vs for vs in vs_list
-                 if vs['vip'][0]['ip_address']['addr'] != '0.0.0.0']
+                 if vs['vsvip_ref'].split('name=')[1].split('-')[0] != '0.0.0.0']
         else:
             avi_config['VirtualService'] = \
                 [vs for vs in vs_list
@@ -917,7 +928,7 @@ class NsUtil(MigrationUtil):
         :param url: url that need to be parsed
         :return:
         """
-        parsed = urlparse.urlparse(url)
+        parsed = urlparse(url)
         return parsed
 
     def format_string_to_json(self, avi_string):
@@ -1396,8 +1407,9 @@ class NsUtil(MigrationUtil):
         for row_data in row_list:
             progressbar_count += 1
             for _key, _value in row_data.items():
-                col = fieldnames.index(_key)
-                status_ws.write(row, col, _value)
+                if _key in fieldnames:
+                    col = fieldnames.index(_key)
+                    status_ws.write(row, col, _value)
             msg = "Writing excel sheet started..."
             self.print_progress_bar(progressbar_count, total_count, msg,
                                prefix='Progress', suffix='')
@@ -1448,7 +1460,7 @@ class NsUtil(MigrationUtil):
         return False
 
     def create_update_vsvip(self, vip, vsvip_config, tenant_ref, cloud_ref,
-                            prefix=None):
+                            prefix=None, vrf_ref=None):
         """
         This functions defines that create or update VSVIP object.
         :param vip: vip of VS
@@ -1456,6 +1468,7 @@ class NsUtil(MigrationUtil):
         :param tenant_ref: tenant reference
         :param cloud_ref: cloud reference
         :param prefix: prefix for objects
+        :param vrf_ref: VRF ref to be added in VIP object
         :return: None
         """
 
@@ -1466,8 +1479,16 @@ class NsUtil(MigrationUtil):
             name = prefix + '-' + name
         vsvip = [vip_obj for vip_obj in vsvip_config
                  if vip_obj['name'] == name]
+        if vsvip:
+            diff_ten = [vips for vips in vsvip if vips['tenant_ref'] !=
+                        tenant_ref]
+            if diff_ten:
+                LOG.debug('VsVip %s is repeated with vrf %s but different '
+                          'tenant %s', name, self.get_name(vrf_ref) if vrf_ref
+                          else 'None', self.get_name(tenant_ref))
+                name = ''
         # If VSVIP object not present then create new VSVIP object.
-        if not vsvip:
+        else:
             vsvip_object = {
                 "name": name,
                 "tenant_ref": tenant_ref,
@@ -1482,6 +1503,8 @@ class NsUtil(MigrationUtil):
                     }
                 ],
             }
+            if vrf_ref:
+                vsvip_object["vrf_context_ref"] = vrf_ref
             vsvip_config.append(vsvip_object)
 
     def get_redirect_fail_action(self, url):
@@ -1490,7 +1513,7 @@ class NsUtil(MigrationUtil):
         :param url: url
         :return:
         """
-        parsed = urlparse.urlparse(url)
+        parsed = urlparse(url)
         redirect_fail_action = {
             'fail_action': {
                 'redirect': {
@@ -1643,7 +1666,7 @@ class NsUtil(MigrationUtil):
         mergelist=[]
         for poolgrp in avi_config['PoolGroup']:
             if poolgrp['name'] == 'lb-depoed1cdb.qai-pri-5984-poolgroup':
-                print 'found'
+                print('found')
             # do not merge the pool if it is a backup pool in the group
             pool_member = [obj for obj in poolgrp['members'] if not
                            obj.get('priority_label', '10') == '2']
